<!---Edit the following according to your PR.-->

## Summary

<!---Include a summary of major changes in bullet points:
* Feature 1
* Feature 2
* Fix 1
* Fix 2
-->

## Additional dependencies introduced (if any)

<!---* List all new dependencies needed and justify why. Provide a justification why
that dependency is needed.-->

## TODO (if any)

<!---Work-in-progress pull requests are encouraged, but please put [WIP]
in the pull request title, and write something about what else needs
to be done
* Feature 1 supports A, but not B.-->


## Checklist

<!---Before a pull request can be merged, the following items must be checked:-->

- [ ] Code is in the [standard Python style](https://www.python.org/dev/peps/pep-0008/).
      Run [pycodestyle](https://pycodestyle.readthedocs.io/en/latest/) and [flake8](http://flake8.pycqa.org/en/latest/)
      on your local machine.
- [ ] Docstrings have been added in the [Google docstring format](https://sphinxcontrib-napoleon.readthedocs.io/en/latest/example_google.html).
      Run [pydocstyle](http://www.pydocstyle.org/en/2.1.1/index.html) on your code.
- [ ] Tests have been added for any new functionality or bug fixes.
- [ ] All existing tests pass.

<!---The CI system will run all the above checks. But it will be much more
efficient if you already fix most errors prior to submitting the PR.-->
